package com.ruoyi.project.production.mapper;

import java.util.List;
import com.ruoyi.framework.aspectj.lang.annotation.DataScope;
import com.ruoyi.project.production.domain.TMonthlyQualityReportS2400;

/**
 * 质量月报S2400Mapper接口
 * 
 * @author ruoyi
 * @date 2023-10-27
 */
public interface TMonthlyQualityReportS2400Mapper 
{
    /**
     * 查询质量月报S2400
     * 
     * @param id 质量月报S2400ID
     * @return 质量月报S2400
     */
    public TMonthlyQualityReportS2400 selectTMonthlyQualityReportS2400ById(Long id);

    /**
     * 查询质量月报S2400列表
     * 
     * @param tMonthlyQualityReportS2400 质量月报S2400
     * @return 质量月报S2400集合
     */
    @DataScope(deptAlias = "d")
    public List<TMonthlyQualityReportS2400> selectTMonthlyQualityReportS2400List(TMonthlyQualityReportS2400 tMonthlyQualityReportS2400);

    /**
     * 新增质量月报S2400
     * 
     * @param tMonthlyQualityReportS2400 质量月报S2400
     * @return 结果
     */
    public int insertTMonthlyQualityReportS2400(TMonthlyQualityReportS2400 tMonthlyQualityReportS2400);

    /**
     * 修改质量月报S2400
     * 
     * @param tMonthlyQualityReportS2400 质量月报S2400
     * @return 结果
     */
    public int updateTMonthlyQualityReportS2400(TMonthlyQualityReportS2400 tMonthlyQualityReportS2400);

    /**
     * 删除质量月报S2400
     * 
     * @param id 质量月报S2400ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS2400ById(Long id);

    /**
     * 批量删除质量月报S2400
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTMonthlyQualityReportS2400ByIds(Long[] ids);
}
